@@ -8,7 +8,7 @@ os.environ['FANART_APIKEY'] = 'e3c7f0d0beeaf45b3a0dd3b9dd8a3338'
 
 class TvItemTestCase(unittest.TestCase):
     @httprettified
-    def test_get(self):
+    def test_get_wilfred(self):
         with open(os.path.join(LOCALDIR, 'response/tv_239761.json')) as fp:
             body = fp.read()
         HTTPretty.register_uri(
@@ -18,3 +18,15 @@ class TvItemTestCase(unittest.TestCase):
         )
         wilfred = TvShow.get(id=239761)
         self.assertEqual(wilfred.tvdbid, '239761')
+
+    @httprettified
+    def test_get_dexter(self):
+        with open(os.path.join(LOCALDIR, 'response/tv_79349.json')) as fp:
+            body = fp.read()
+        HTTPretty.register_uri(
+            HTTPretty.GET,
+            'http://api.fanart.tv/webservice/series/e3c7f0d0beeaf45b3a0dd3b9dd8a3338/79349/JSON/all/1/2',
+            body=body
+        )
+        dexter = TvShow.get(id=79349)
+        self.assertEqual(dexter.tvdbid, '79349')
